@@ -72,7 +72,7 @@ void IndicatorSoundTestBase::SetUp()
                             "GetCapabilities",
                             "",
                             "as",
-                            "ret = ['actions', 'body', 'body-markup', 'icon-static', 'image/svg+xml', 'x-canonical-private-synchronous', 'x-canonical-append', 'x-canonical-private-icon-only', 'x-canonical-truncation', 'private-synchronous', 'append', 'private-icon-only', 'truncation']"
+                            "ret = ['actions', 'body', 'body-markup', 'icon-static', 'image/svg+xml', 'x-lomiri-private-synchronous', 'x-canonical-append', 'x-lomiri-private-icon-only', 'x-lomiri-truncation', 'x-canonical-truncation', 'private-synchronous', 'append', 'private-icon-only', 'truncation']"
                          ).waitForFinished();
 
     int waitedTime = 0;
@@ -649,12 +649,12 @@ void IndicatorSoundTestBase::checkVolumeNotification(double volume, QString cons
     ASSERT_TRUE(hints.contains("value"));
     ASSERT_TRUE(hints.contains("x-lomiri-non-shaped-icon"));
     ASSERT_TRUE(hints.contains("x-lomiri-value-bar-tint"));
-    ASSERT_TRUE(hints.contains("x-canonical-private-synchronous"));
+    ASSERT_TRUE(hints.contains("x-lomiri-private-synchronous"));
 
     EXPECT_EQ(volume*100, hints["value"]);
     EXPECT_EQ(true, hints["x-lomiri-non-shaped-icon"]);
     EXPECT_EQ(isLoud, hints["x-lomiri-value-bar-tint"]);
-    EXPECT_EQ(true, hints["x-canonical-private-synchronous"]);
+    EXPECT_EQ(true, hints["x-lomiri-private-synchronous"]);
 }
 
 void IndicatorSoundTestBase::checkHighVolumeNotification(QVariantList call)
