@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2015 Canonical, Ltd.
+ * Copyright (C) 2015 Canonical Ltd.
+ * Copyright (C) 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -13,11 +14,13 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Author: Xavi Garcia <xavi.garcia.mena@canonical.com>
+ * Authors:
+ *      Xavi Garcia <xavi.garcia.mena@canonical.com>
+ *      Robert Tari <robert@tari.in>
  */
 #pragma once
 
-namespace ubuntu
+namespace ayatana
 {
 
 namespace indicators
@@ -28,13 +31,10 @@ namespace testing
     constexpr const char ACCOUNTS_SERVICE[] = "org.freedesktop.Accounts";
     constexpr const char USER_PATH[] = "/org/freedesktop/Accounts/UserTest";
     constexpr const char ACCOUNTS_PATH[] = "/org/freedesktop/Accounts";
-#ifdef HAS_UT_ACCTSERVICE_SOUND_SETTINGS
-    constexpr const char ACCOUNTS_SOUND_INTERFACE[] = "com.ubuntu.AccountsService.Sound";
-#else
-    constexpr const char ACCOUNTS_SOUND_INTERFACE[] = "org.ayatana.AccountsService.Sound";
-#endif
+    constexpr const char ACCOUNTS_SOUND_INTERFACE[] = "com.lomiri.AccountsService.Sound";
+
 } // namespace testing
 
 } // namespace indicators
 
-} // namespace ubuntu
+} // namespace ayatana
